summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/dialogs/tqprintdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/dialogs/tqprintdialog.cpp')
-rw-r--r--experimental/tqtinterface/qt4/src/dialogs/tqprintdialog.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/experimental/tqtinterface/qt4/src/dialogs/tqprintdialog.cpp b/experimental/tqtinterface/qt4/src/dialogs/tqprintdialog.cpp
index eb4a7948f..d4f247268 100644
--- a/experimental/tqtinterface/qt4/src/dialogs/tqprintdialog.cpp
+++ b/experimental/tqtinterface/qt4/src/dialogs/tqprintdialog.cpp
@@ -170,7 +170,7 @@ public:
: TQListViewItem( printers, name, host, comment ), ali( aliases ) { }
bool samePrinter( const TQString& name ) {
- return text( 0 ) == name || ali.tqfind( name ) != ali.end();
+ return text( 0 ) == name || ali.find( name ) != ali.end();
}
TQStringList ali;
@@ -199,13 +199,13 @@ static void parsePrinterDesc( TQString printerDesc, TQListView * printers )
return;
printerDesc = printerDesc.simplifyWhiteSpace();
- int i = printerDesc.tqfind( ':' );
+ int i = printerDesc.find( ':' );
TQString printerName, printerComment, printerHost;
TQStringList aliases;
if ( i >= 0 ) {
// have ':' want '|'
- int j = printerDesc.tqfind( '|' );
+ int j = printerDesc.find( '|' );
if ( j > 0 && j < i ) {
printerName = printerDesc.left( j );
aliases = TQStringList::split( '|',
@@ -217,11 +217,11 @@ static void parsePrinterDesc( TQString printerDesc, TQListView * printers )
printerName = printerDesc.left( i );
}
// look for lprng pseudo all printers entry
- i = printerDesc.tqfind( TQRegExp(TQString::tqfromLatin1(": *all *=")) );
+ i = printerDesc.find( TQRegExp(TQString::tqfromLatin1(": *all *=")) );
if ( i >= 0 )
printerName = "";
// look for signs of this being a remote printer
- i = printerDesc.tqfind( TQRegExp(TQString::tqfromLatin1(": *rm *=")) );
+ i = printerDesc.find( TQRegExp(TQString::tqfromLatin1(": *rm *=")) );
if ( i >= 0 ) {
// point k at the end of remote host name
while ( printerDesc[i] != '=' )
@@ -382,17 +382,17 @@ static char * parsePrintersConf( TQListView * printers, bool *found = 0 )
} else {
printerDesc += TQString::fromLocal8Bit(line);
printerDesc = printerDesc.simplifyWhiteSpace();
- int i = printerDesc.tqfind( ':' );
+ int i = printerDesc.find( ':' );
TQString printerName, printerHost, printerComment;
TQStringList aliases;
if ( i >= 0 ) {
// have : want |
- int j = printerDesc.tqfind( '|', 0 );
+ int j = printerDesc.find( '|', 0 );
if ( j >= i )
j = -1;
printerName = printerDesc.mid( 0, j < 0 ? i : j );
if ( printerName == TQString::tqfromLatin1("_default") ) {
- i = printerDesc.tqfind(
+ i = printerDesc.find(
TQRegExp( TQString::tqfromLatin1(": *use *=") ) );
while ( printerDesc[i] != '=' )
i++;
@@ -421,7 +421,7 @@ static char * parsePrintersConf( TQListView * printers, bool *found = 0 )
.arg( aliases.join(", ") );
}
// look for signs of this being a remote printer
- i = printerDesc.tqfind(
+ i = printerDesc.find(
TQRegExp( TQString::tqfromLatin1(": *bsdaddr *=") ) );
if ( i >= 0 ) {
// point k at the end of remote host name
@@ -635,7 +635,7 @@ static void parseEtcLpMember( TQListView * printers )
++it;
// I haven't found any real documentation, so I'm guessing that
// since lpstat uses /etc/lp/member rather than one of the
// other directories, it's the one to use. I did not tqfind a
// decent way to locate aliases and remote printers.
if ( printer->isFile() )
perhapsAddPrinter( printers, printer->fileName(),
@@ -698,11 +698,11 @@ static void parseSpoolInterface( TQListView * printers )
configFile.close();
printerType = printerType.stripWhiteSpace();
- if ( printerType.tqfind("postscript", 0, FALSE) < 0 )
+ if ( printerType.find("postscript", 0, FALSE) < 0 )
continue;
int ii = 0;
- while ( (ii = namePrinter.tqfind('"', ii)) >= 0 )
+ while ( (ii = namePrinter.find('"', ii)) >= 0 )
namePrinter.remove( ii, 1 );
if ( hostName.isEmpty() || hostPrinter.isEmpty() ) {
@@ -751,7 +751,7 @@ static void parseQconfig( TQListView * printers )
bool indented = line[0].isSpace();
line = line.simplifyWhiteSpace();
- int i = line.tqfind('=');
+ int i = line.find('=');
if ( indented && i != -1 ) { // line in stanza
TQString variable = TQT_TQSTRING(line.left( i )).simplifyWhiteSpace();
TQString value=TQT_TQSTRING(line.mid( i+1, line.length() )).simplifyWhiteSpace();
@@ -764,7 +764,7 @@ static void parseQconfig( TQListView * printers )
} else if ( line[0] == '*' ) { // comment
// nothing to do
} else if ( ts.atEnd() || // end of file, or beginning of new stanza
- ( !indented && line.tqfind( newStanza ) != -1 ) ) {
+ ( !indented && line.find( newStanza ) != -1 ) ) {
if ( up && stanzaName.length() > 0 && stanzaName.length() < 21 ) {
if ( remoteHost.length() ) // remote printer
perhapsAddPrinter( printers, stanzaName, remoteHost,
@@ -1087,7 +1087,7 @@ TQGroupBox * TQPrintDialog::setupDestination()
}
}
// all printers hopefully known. try to tqfind a good default
TQString dollarPrinter;
{
const char * t = getenv( "PRINTER" );
@@ -635,7 +635,7 @@ static void parseEtcLpMember( TQListView * printers )
// I haven't found any real documentation, so I'm guessing that
// since lpstat uses /etc/lp/member rather than one of the
- // other directories, it's the one to use. I did not tqfind a
+ // other directories, it's the one to use. I did not find a
// decent way to locate aliases and remote printers.
if ( printer->isFile() )
@@ -1087,7 +1087,7 @@ TQGroupBox * TQPrintDialog::setupDestination()
}
}
- // all printers hopefully known. try to tqfind a good default
+ // all printers hopefully known. try to find a good default
TQString dollarPrinter;
{